netapp_ontap.models.shelf_cable API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_cable`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfCableSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfCable object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `identifier GET POST PATCH`

    The identifier field of the shelf_cable.

    Example: 500a0980000b6c3f-50000d1703544b80

  `length GET POST PATCH`

    The length field of the shelf_cable.

    Example: 2m

  `part_number GET POST PATCH`

    The part_number field of the shelf_cable.

    Example: 112-00431+A0

  `serial_number GET POST PATCH`

    The serial_number field of the shelf_cable.

    Example: 616930439